@@ -50,6 +50,7 @@ extern const module_t mx6sl[];
 extern const module_t mx6sx[];
 extern const module_t mx6ul[];
 extern const module_t mx7d[];
+extern const module_t mx6ull[];
 
 char g_buffer[4096];
 
@@ -331,6 +332,8 @@ void parse_module(char *module, char *reg, char *field, int iswrite)
 			mx = mx6ul;
 		else if (!strcmp(soc_name, "i.MX7D"))
 			mx = mx7d;
+		else if (!strcmp(soc_name, "i.MX6ULL"))
+			mx = mx6ull;
 		else
 			die("Unknown SOC\n");
 	}
